# NEXT RELEASE

## O.4.0
* Improve Tweet matching
* Improve logging
* Rename to `clown_sort`

### 0.3.1
* Logging adjustments

## 0.3.0
* `--show-rules` argument, `--debug` argument
* More sorting rules
* Logging adjustments

### 0.2.3
* Logging adjustments.

### 0.2.2
* Copy non image files so they can be sent to multiple folders.

### 0.2.1
* Preserve all timestamps

## 0.2.0
* More command line args

# 0.1.0
* Initial release.
